@@ -1,6 +1,7 @@
 /* gnome-rr.h
  *
  * Copyright 2007, 2008, Red Hat, Inc.
+ * Copyright 2020 NVIDIA CORPORATION
  * 
  * This file is part of the Gnome Library.
  * 
@@ -75,7 +76,7 @@ typedef struct {
      * Conversion matrix in S31.32 sign-magnitude (not two's complement!)
      * format.
      */
-    uint64_t matrix[9];
+    guint64 matrix[9];
 } GnomeRRCTM;
 
 /* Error codes */
